@@ -6,11 +6,10 @@
     :copyright: (c) 2013, SoftLayer Technologies, Inc. All rights reserved.
     :license: MIT, see LICENSE for more details.
 """
-import datetime
+import time
 
 from consts import API_PUBLIC_ENDPOINT, API_PRIVATE_ENDPOINT, USER_AGENT
 from transports import make_xml_rpc_api_call
-from exceptions import SoftLayerError
 from auth import TokenAuthentication
 from config import get_client_settings
 
@@ -23,6 +22,7 @@ VALID_CALL_ARGS = set([
     'mask',
     'filter',
     'headers',
+    'compress',
     'raw_headers',
     'limit',
     'offset',
@@ -141,6 +141,7 @@ class Client(object):
         objectmask = kwargs.get('mask')
         objectfilter = kwargs.get('filter')
         headers = kwargs.get('headers', {})
+        compress = kwargs.get('compress', True)
         raw_headers = kwargs.get('raw_headers')
         limit = kwargs.get('limit')
         offset = kwargs.get('offset', 0)
@@ -149,7 +150,7 @@ class Client(object):
             headers.update(self.auth.get_headers())
 
         if objectid is not None:
-            headers[service + 'InitParameters'] = {'id': int(objectid)}
+            headers[service + 'InitParameters'] = {'id': objectid}
 
         if objectmask is not None:
             headers.update(self.__format_object_mask(objectmask, service))
@@ -159,14 +160,19 @@ class Client(object):
 
         if limit:
             headers['resultLimit'] = {
-                'limit': int(limit),
-                'offset': int(offset)
+                'limit': limit,
+                'offset': offset,
             }
 
         http_headers = {
             'User-Agent': USER_AGENT,
             'Content-Type': 'application/xml',
         }
+
+        if compress:
+            http_headers['Accept'] = '*/*'
+            http_headers['Accept-Encoding'] = 'gzip, deflate, compress'
+
         if raw_headers:
             http_headers.update(raw_headers)
 
@@ -242,15 +248,9 @@ class Client(object):
             mheader = self._prefix + 'ObjectMask'
 
             objectmask = objectmask.strip()
-            if objectmask.startswith('mask'):
-                objectmask = objectmask[4:]
-                if objectmask[0] == '.':
-                    objectmask = objectmask[1:]
-                elif objectmask[0] == '[' and objectmask[-1] == ']':
-                    objectmask = objectmask[1:-1]
-                else:
-                    raise SoftLayerError('Malformed Mask: %s' % objectmask)
-            objectmask = "mask[%s]" % objectmask
+            if not objectmask.startswith('mask') \
+                    and not objectmask.startswith('['):
+                objectmask = "mask[%s]" % objectmask
 
         return {mheader: {'mask': objectmask}}
 
@@ -272,14 +272,12 @@ class TimedClient(Client):
 
     def call(self, service, method, *args, **kwargs):
         """ See Client.call for documentation. """
-        start_time = datetime.datetime.utcnow()
+        start_time = time.time()
         result = super(TimedClient, self).call(service, method, *args,
                                                **kwargs)
-        end_time = datetime.datetime.utcnow()
+        end_time = time.time()
         diff = end_time - start_time
-        self.last_calls.append((service + '.' + method,
-                                start_time.strftime('%s'),
-                                diff.total_seconds()))
+        self.last_calls.append((service + '.' + method, start_time, diff))
         return result
 
     def get_last_calls(self):
@@ -307,6 +305,7 @@ class Service(object):
         :param mask: (optional) object mask
         :param dict filter: (optional) filter dict
         :param dict headers: (optional) optional XML-RPC headers
+        :param boolean compress: (optional) Enable/Disable HTTP compression
         :param dict raw_headers: (optional) HTTP transport headers
         :param int limit: (optional) return at most this many results
         :param int offset: (optional) offset results by this many
