@@ -17,13 +17,14 @@ Compute:
   sshkey    Manage SSH keys on your account
 
 Networking:
-  dns       Domain Name System
-  firewall  Firewall rule and security management
-  globalip  Global IP address management
-  rwhois    RWhoIs operations
-  ssl       Manages SSL
-  subnet    Subnet ordering and management
-  vlan      Manage VLANs on your account
+  dns        Domain Name System
+  firewall   Firewall rule and security management
+  globalip   Global IP address management
+  messaging  Message Queue Service
+  rwhois     RWhoIs operations
+  ssl        Manages SSL
+  subnet     Subnet ordering and management
+  vlan       Manage VLANs on your account
 
 Storage:
   iscsi     View iSCSI details
@@ -50,8 +51,7 @@ from docopt import docopt, DocoptExit
 from SoftLayer import Client, TimedClient, SoftLayerError, SoftLayerAPIError
 from SoftLayer.consts import VERSION
 from helpers import CLIAbort, ArgumentError, format_output, KeyValueTable
-from environment import (
-    Environment, CLIRunnableType, InvalidCommand, InvalidModule)
+from environment import Environment, InvalidCommand, InvalidModule
 
 
 DEBUG_LOGGING_MAP = {
@@ -120,8 +120,7 @@ Standard Options:
             version=VERSION,
             argv=[module_name] + args,
             options_first=True)
-        module = self.env.load_module(module_name)
-        return module, arguments
+        return arguments
 
     def parse_command_args(self, module_name, command_name, args):
         command = self.env.get_command(module_name, command_name)
@@ -135,8 +134,7 @@ Standard Options:
         module_name = main_args['<module>']
 
         # handle `sl <module> ...`
-        module, module_args = self.parse_module_args(
-            module_name, main_args['<args>'])
+        module_args = self.parse_module_args(module_name, main_args['<args>'])
 
         # get the command argument
         command_name = module_args.get('<command>')
@@ -153,7 +151,6 @@ def main(args=sys.argv[1:], env=Environment()):
     Entry point for the command-line client.
     """
     # Parse Top-Level Arguments
-    CLIRunnableType.env = env
     exit_status = 0
     resolver = CommandParser(env)
     try:
@@ -173,24 +170,25 @@ def main(args=sys.argv[1:], env=Environment()):
             client = Client(config_file=command_args.get('--config'))
 
         # Do the thing
-        data = command.execute(client, command_args)
+        runnable = command(client=client, env=env)
+        data = runnable.execute(command_args)
         if data:
-            format = command_args.get('--format', 'table')
-            if format not in VALID_FORMATS:
-                raise ArgumentError('Invalid format "%s"' % format)
-            s = format_output(data, fmt=format)
+            out_format = command_args.get('--format', 'table')
+            if out_format not in VALID_FORMATS:
+                raise ArgumentError('Invalid format "%s"' % out_format)
+            s = format_output(data, fmt=out_format)
             if s:
                 env.out(s)
 
         if command_args.get('--timings'):
-            format = command_args.get('--format', 'table')
+            out_format = command_args.get('--format', 'table')
             api_calls = client.get_last_calls()
             t = KeyValueTable(['call', 'time'])
 
-            for call, initiated, duration in api_calls:
+            for call, _, duration in api_calls:
                 t.add_row([call, duration])
 
-            env.err(format_output(t, fmt=format))
+            env.err(format_output(t, fmt=out_format))
 
     except InvalidCommand as e:
         env.err(resolver.get_module_help(e.module_name))
@@ -198,7 +196,7 @@ def main(args=sys.argv[1:], env=Environment()):
             env.err('')
             env.err(str(e))
             exit_status = 1
-    except InvalidModule, e:
+    except InvalidModule as e:
         env.err(resolver.get_main_help())
         if e.module_name:
             env.err('')
