@@ -30,14 +30,15 @@ hostname or the ip address for a CCI.
 from os import linesep
 import os.path
 
-from SoftLayer import CCIManager, SshKeyManager, DNSManager
+from SoftLayer import CCIManager, SshKeyManager, DNSManager, DNSZoneNotFound
 from SoftLayer.utils import lookup
 from SoftLayer.CLI import (
     CLIRunnable, Table, no_going_back, confirm, mb_to_gb, listing,
     FormattedItem)
 from SoftLayer.CLI.helpers import (
     CLIAbort, ArgumentError, NestedDict, blank, resolve_id, KeyValueTable,
-    update_with_template_args, FALSE_VALUES, export_to_template)
+    update_with_template_args, FALSE_VALUES, export_to_template,
+    active_txn)
 
 
 class ListCCIs(CLIRunnable):
@@ -73,9 +74,8 @@ For more on filters see 'sl help filters'
 """
     action = 'list'
 
-    @staticmethod
-    def execute(client, args):
-        cci = CCIManager(client)
+    def execute(self, args):
+        cci = CCIManager(self.client)
 
         tags = None
         if args.get('--tags'):
@@ -103,14 +103,13 @@ For more on filters see 'sl help filters'
             guest = NestedDict(guest)
             t.add_row([
                 guest['id'],
-                guest['datacenter']['name'],
+                guest['datacenter']['name'] or blank(),
                 guest['fullyQualifiedDomainName'],
                 guest['maxCpu'],
                 mb_to_gb(guest['maxMemory']),
                 guest['primaryIpAddress'] or blank(),
                 guest['primaryBackendIpAddress'] or blank(),
-                guest['activeTransaction']['transactionStatus'].get(
-                    'friendlyName') or blank(),
+                active_txn(guest),
             ])
 
         return t
@@ -128,9 +127,8 @@ Options:
 """
     action = 'detail'
 
-    @staticmethod
-    def execute(client, args):
-        cci = CCIManager(client)
+    def execute(self, args):
+        cci = CCIManager(self.client)
         t = KeyValueTable(['Name', 'Value'])
         t.align['Name'] = 'r'
         t.align['Value'] = 'l'
@@ -145,20 +143,21 @@ Options:
             result['status']['keyName'] or blank(),
             result['status']['name'] or blank()
         )])
+        t.add_row(['active_transaction', active_txn(result)])
         t.add_row(['state', FormattedItem(
             lookup(result, 'powerState', 'keyName'),
             lookup(result, 'powerState', 'name'),
         )])
-        t.add_row(['datacenter', result['datacenter']['name']])
+        t.add_row(['datacenter', result['datacenter']['name'] or blank()])
         operating_system = lookup(result,
                                   'operatingSystem',
                                   'softwareLicense',
-                                  'softwareDescription')
+                                  'softwareDescription') or {}
         t.add_row([
             'os',
             FormattedItem(
-                operating_system['version'] or blank(),
-                operating_system['name'] or blank()
+                operating_system.get('version') or blank(),
+                operating_system.get('name') or blank()
             )])
         t.add_row(['os_version', operating_system['version'] or blank()])
         t.add_row(['cores', result['maxCpu']])
@@ -196,7 +195,7 @@ Options:
             t.add_row(['tags', listing(tag_row, separator=',')])
 
         if not result['privateNetworkOnlyFlag']:
-            ptr_domains = client['Virtual_Guest'].\
+            ptr_domains = self.client['Virtual_Guest'].\
                 getReverseDomainRecords(id=cci_id)
 
             for ptr_domain in ptr_domains:
@@ -224,13 +223,12 @@ Options:
     action = 'create-options'
     options = ['datacenter', 'cpu', 'nic', 'disk', 'os', 'memory']
 
-    @classmethod
-    def execute(cls, client, args):
-        cci = CCIManager(client)
+    def execute(self, args):
+        cci = CCIManager(self.client)
         result = cci.get_create_options()
 
         show_all = True
-        for opt_name in cls.options:
+        for opt_name in self.options:
             if args.get("--" + opt_name):
                 show_all = False
                 break
@@ -337,7 +335,7 @@ Options:
 
 class CreateCCI(CLIRunnable):
     """
-usage: sl cci create [--key=KEY...] [options]
+usage: sl cci create [--disk=SIZE...] [--key=KEY...] [options]
 
 Order/create a CCI. See 'sl cci create-options' for valid options
 
@@ -367,6 +365,7 @@ Optional:
                            multiple times
   --like=IDENTIFIER      Use the configuration from an existing CCI
   -n, --network=MBPS     Network port speed in Mbps
+  -d, --disk=SIZE...     Disks. Can be specified multiple times
   --private              Forces the CCI to only have access the private
                            network
   -t, --template=FILE    A template file that defaults the command-line
@@ -383,17 +382,20 @@ Optional:
     options = ['confirm']
     required_params = ['--hostname', '--domain', '--cpu', '--memory']
 
-    @classmethod
-    def execute(cls, client, args):
+    def execute(self, args):
         update_with_template_args(args)
-        cci = CCIManager(client)
-        cls._update_with_like_args(cci, args)
+        cci = CCIManager(self.client)
+        self._update_with_like_args(args)
+
+        # Disks will be a comma-separated list. Let's make it a real list.
+        if isinstance(args.get('--disk'), str):
+            args['--disk'] = args.get('--disk').split(',')
 
         # SSH keys may be a comma-separated list. Let's make it a real list.
         if isinstance(args.get('--key'), str):
             args['--key'] = args.get('--key').split(',')
 
-        cls._validate_args(args)
+        self._validate_args(args)
 
         # Do not create CCI with --test or --export
         do_create = not (args['--export'] or args['--test'])
@@ -401,7 +403,7 @@ Optional:
         t = Table(['Item', 'cost'])
         t.align['Item'] = 'r'
         t.align['cost'] = 'r'
-        data = cls._parse_create_args(client, args)
+        data = self._parse_create_args(args)
 
         output = []
         if args.get('--test'):
@@ -467,9 +469,8 @@ Optional:
 
         return output
 
-    @classmethod
-    def _validate_args(cls, args):
-        invalid_args = [k for k in cls.required_params if args.get(k) is None]
+    def _validate_args(self, args):
+        invalid_args = [k for k in self.required_params if args.get(k) is None]
         if invalid_args:
             raise ArgumentError('Missing required options: %s'
                                 % ','.join(invalid_args))
@@ -503,14 +504,14 @@ Optional:
                     'File does not exist [-u | --userfile] = %s'
                     % args['--userfile'])
 
-    @staticmethod
-    def _update_with_like_args(cci, args):
+    def _update_with_like_args(self, args):
         """ Update arguments with options taken from a currently running CCI.
 
         :param CCIManager args: A CCIManager
         :param dict args: CLI arguments
         """
         if args['--like']:
+            cci = CCIManager(self.client)
             cci_id = resolve_id(cci.resolve_ids, args.pop('--like'), 'CCI')
             like_details = cci.get_instance(cci_id)
             like_args = {
@@ -553,8 +554,7 @@ Optional:
                 if args.get(key) in [None, False]:
                     args[key] = value
 
-    @staticmethod
-    def _parse_create_args(client, args):
+    def _parse_create_args(self, args):
         """ Converts CLI arguments to arguments that can be passed into
             CCIManager.create_instance.
 
@@ -567,6 +567,7 @@ Optional:
             "hostname": args['--hostname'],
             "private": args['--private'],
             "dedicated": args['--dedicated'],
+            "disks": args['--disk'],
             "local_disk": True,
         }
 
@@ -615,8 +616,8 @@ Optional:
         if args.get('--key'):
             keys = []
             for key in args.get('--key'):
-                key_id = resolve_id(SshKeyManager(client).resolve_ids, key,
-                                    'SshKey')
+                key_id = resolve_id(SshKeyManager(self.client).resolve_ids,
+                                    key, 'SshKey')
                 keys.append(key_id)
             data['ssh_keys'] = keys
 
@@ -641,9 +642,8 @@ Optional:
 """
     action = 'ready'
 
-    @staticmethod
-    def execute(client, args):
-        cci = CCIManager(client)
+    def execute(self, args):
+        cci = CCIManager(self.client)
 
         cci_id = resolve_id(cci.resolve_ids, args.get('<identifier>'), 'CCI')
         ready = cci.wait_for_transaction(cci_id, int(args.get('--wait') or 0))
@@ -656,24 +656,31 @@ Optional:
 
 class ReloadCCI(CLIRunnable):
     """
-usage: sl cci reload <identifier> [options]
+usage: sl cci reload <identifier> [--key=KEY...] [options]
 
 Reload the OS on a CCI based on its current configuration
 
 Optional:
-    -i, --postinstall=URI  Post-install script to download
-                             (Only HTTPS executes, HTTP leaves file in /root)
+  -i, --postinstall=URI  Post-install script to download
+                           (Only HTTPS executes, HTTP leaves file in /root)
+  -k, --key=KEY          SSH keys to add to the root user. Can be specified
+                           multiple times
 """
 
     action = 'reload'
     options = ['confirm']
 
-    @staticmethod
-    def execute(client, args):
-        cci = CCIManager(client)
+    def execute(self, args):
+        cci = CCIManager(self.client)
         cci_id = resolve_id(cci.resolve_ids, args.get('<identifier>'), 'CCI')
+        keys = []
+        if args.get('--key'):
+            for key in args.get('--key'):
+                key_id = resolve_id(SshKeyManager(self.client).resolve_ids,
+                                    key, 'SshKey')
+                keys.append(key_id)
         if args['--really'] or no_going_back(cci_id):
-            cci.reload_instance(cci_id, args['--postinstall'])
+            cci.reload_instance(cci_id, args['--postinstall'], keys)
         else:
             CLIAbort('Aborted')
 
@@ -688,9 +695,8 @@ Cancel a CCI
     action = 'cancel'
     options = ['confirm']
 
-    @staticmethod
-    def execute(client, args):
-        cci = CCIManager(client)
+    def execute(self, args):
+        cci = CCIManager(self.client)
         cci_id = resolve_id(cci.resolve_ids, args.get('<identifier>'), 'CCI')
         if args['--really'] or no_going_back(cci_id):
             cci.cancel_instance(cci_id)
@@ -710,10 +716,9 @@ Optional:
     action = 'power-off'
     options = ['confirm']
 
-    @classmethod
-    def execute(cls, client, args):
-        vg = client['Virtual_Guest']
-        cci = CCIManager(client)
+    def execute(self, args):
+        vg = self.client['Virtual_Guest']
+        cci = CCIManager(self.client)
         cci_id = resolve_id(cci.resolve_ids, args.get('<identifier>'), 'CCI')
         if args['--really'] or confirm('This will power off the CCI with id '
                                        '%s. Continue?' % cci_id):
@@ -738,10 +743,9 @@ Optional:
     action = 'reboot'
     options = ['confirm']
 
-    @classmethod
-    def execute(cls, client, args):
-        vg = client['Virtual_Guest']
-        cci = CCIManager(client)
+    def execute(self, args):
+        vg = self.client['Virtual_Guest']
+        cci = CCIManager(self.client)
         cci_id = resolve_id(cci.resolve_ids, args.get('<identifier>'), 'CCI')
         if args['--really'] or confirm('This will reboot the CCI with id '
                                        '%s. Continue?' % cci_id):
@@ -763,10 +767,9 @@ Power on a CCI
 """
     action = 'power-on'
 
-    @classmethod
-    def execute(cls, client, args):
-        vg = client['Virtual_Guest']
-        cci = CCIManager(client)
+    def execute(self, args):
+        vg = self.client['Virtual_Guest']
+        cci = CCIManager(self.client)
         cci_id = resolve_id(cci.resolve_ids, args.get('<identifier>'), 'CCI')
         vg.powerOn(id=cci_id)
 
@@ -780,10 +783,9 @@ Pauses an active CCI
     action = 'pause'
     options = ['confirm']
 
-    @classmethod
-    def execute(cls, client, args):
-        vg = client['Virtual_Guest']
-        cci = CCIManager(client)
+    def execute(self, args):
+        vg = self.client['Virtual_Guest']
+        cci = CCIManager(self.client)
         cci_id = resolve_id(cci.resolve_ids, args.get('<identifier>'), 'CCI')
 
         if args['--really'] or confirm('This will pause the CCI with id '
@@ -801,10 +803,9 @@ Resumes a paused CCI
 """
     action = 'resume'
 
-    @classmethod
-    def execute(cls, client, args):
-        vg = client['Virtual_Guest']
-        cci = CCIManager(client)
+    def execute(self, args):
+        vg = self.client['Virtual_Guest']
+        cci = CCIManager(self.client)
         cci_id = resolve_id(cci.resolve_ids, args.get('<identifier>'), 'CCI')
         vg.resume(id=cci_id)
 
@@ -821,11 +822,10 @@ Options:
 """
     action = 'nic-edit'
 
-    @classmethod
-    def execute(cls, client, args):
+    def execute(self, args):
         public = args['public']
 
-        cci = CCIManager(client)
+        cci = CCIManager(self.client)
         cci_id = resolve_id(cci.resolve_ids, args.get('<identifier>'), 'CCI')
 
         cci.change_port_speed(cci_id, public, args['--speed'])
@@ -848,17 +848,14 @@ Options:
     action = 'dns'
     options = ['confirm']
 
-    @classmethod
-    def execute(cls, client, args):
-        args['--ttl'] = args['--ttl'] or DNSManager.DEFAULT_TTL
+    def execute(self, args):
+        args['--ttl'] = args['--ttl'] or 7200
         if args['sync']:
-            return cls.dns_sync(client, args)
+            return self.dns_sync(args)
 
-    @staticmethod
-    def dns_sync(client, args):
-        from SoftLayer import DNSManager, DNSZoneNotFound
-        dns = DNSManager(client)
-        cci = CCIManager(client)
+    def dns_sync(self, args):
+        dns = DNSManager(self.client)
+        cci = CCIManager(self.client)
 
         cci_id = resolve_id(cci.resolve_ids, args.get('<identifier>'), 'CCI')
         instance = cci.get_instance(cci_id)
@@ -890,7 +887,7 @@ Options:
 
         def sync_ptr_record():
             host_rec = instance['primaryIpAddress'].split('.')[-1]
-            ptr_domains = client['Virtual_Guest'].\
+            ptr_domains = self.client['Virtual_Guest'].\
                 getReverseDomainRecords(id=instance['id'])[0]
             edit_ptr = None
             for ptr in ptr_domains['resourceRecords']:
@@ -951,8 +948,7 @@ Options:
 """
     action = 'edit'
 
-    @staticmethod
-    def execute(client, args):
+    def execute(self, args):
         data = {}
 
         if args['--userdata'] and args['--userfile']:
@@ -976,7 +972,7 @@ Options:
         data['hostname'] = args.get('--hostname')
         data['domain'] = args.get('--domain')
 
-        cci = CCIManager(client)
+        cci = CCIManager(self.client)
         cci_id = resolve_id(cci.resolve_ids, args.get('<identifier>'), 'CCI')
         if not cci.edit(cci_id, **data):
             raise CLIAbort("Failed to update CCI")
