@@ -7,7 +7,7 @@ The available commands are:
   list  List active vlans with firewalls
 """
 # :copyright: (c) 2013, SoftLayer Technologies, Inc. All rights reserved.
-# :license: BSD, see LICENSE for more details.
+# :license: MIT, see LICENSE for more details.
 
 from SoftLayer.CLI import CLIRunnable, Table, listing
 from SoftLayer.CLI.helpers import blank
@@ -22,9 +22,8 @@ List active vlans with firewalls
 """
     action = 'list'
 
-    @staticmethod
-    def execute(client, args):
-        f = FirewallManager(client)
+    def execute(self, args):
+        f = FirewallManager(self.client)
         fwvlans = f.get_firewalls()
         t = Table(['vlan', 'type', 'features'])
 
