@@ -6,7 +6,7 @@ usage: sl help [options]
 View help on a module or command.
 """
 # :copyright: (c) 2013, SoftLayer Technologies, Inc. All rights reserved.
-# :license: BSD, see LICENSE for more details.
+# :license: MIT, see LICENSE for more details.
 
 from SoftLayer.CLI.core import CommandParser
 from SoftLayer.CLI import CLIRunnable
@@ -17,10 +17,9 @@ class Show(CLIRunnable):
     __doc__ = __doc__
     action = None
 
-    @classmethod
-    def execute(cls, client, args):
-        parser = CommandParser(cls.env)
-        cls.env.load_module(args['<module>'])
+    def execute(self, args):
+        parser = CommandParser(self.env)
+        self.env.load_module(args['<module>'])
         if args['<command>']:
             return parser.get_command_help(args['<module>'], args['<command>'])
         elif args['<module>']:
