@@ -4,10 +4,10 @@ usage: sl image [<command>] [<args>...] [options]
 Manage compute and flex images
 
 The available commands are:
-  list  List active vlans with firewalls
+  list  List images
 """
 # :copyright: (c) 2013, SoftLayer Technologies, Inc. All rights reserved.
-# :license: BSD, see LICENSE for more details.
+# :license: MIT, see LICENSE for more details.
 
 from SoftLayer.CLI import CLIRunnable, Table
 from SoftLayer.CLI.helpers import blank
@@ -17,30 +17,29 @@ class ListImages(CLIRunnable):
     """
 usage: sl image list [--public | --private] [options]
 
-List images on the account
+List images
 
 Options:
-  --public   Display only public images
   --private  Display only private images
+  --public   Display only public images
 """
     action = 'list'
 
-    @staticmethod
-    def execute(client, args):
-        account = client['Account']
+    def execute(self, args):
+        account = self.client['Account']
 
         neither = not any([args['--private'], args['--public']])
 
         results = []
         if args['--private'] or neither:
-            account = client['Account']
+            account = self.client['Account']
             mask = 'id,accountId,name,globalIdentifier,blockDevices,parentId'
             r = account.getPrivateBlockDeviceTemplateGroups(mask=mask)
 
             results.append(r)
 
         if args['--public'] or neither:
-            vgbd = client['Virtual_Guest_Block_Device_Template_Group']
+            vgbd = self.client['Virtual_Guest_Block_Device_Template_Group']
             r = vgbd.getPublicImages()
 
             results.append(r)
