@@ -7,7 +7,7 @@ The available commands are:
   list  List NAS accounts
 """
 # :copyright: (c) 2013, SoftLayer Technologies, Inc. All rights reserved.
-# :license: BSD, see LICENSE for more details.
+# :license: MIT, see LICENSE for more details.
 
 from SoftLayer.CLI import CLIRunnable, Table, FormattedItem
 from SoftLayer.CLI.helpers import NestedDict, blank
@@ -23,9 +23,8 @@ Options:
 """
     action = 'list'
 
-    @staticmethod
-    def execute(client, args):
-        account = client['Account']
+    def execute(self, args):
+        account = self.client['Account']
 
         nas = account.getNasNetworkStorage(
             mask='eventCount,serviceResource[datacenter.name]')
