@@ -4,7 +4,7 @@
     Exceptions used throughout the library
 
     :copyright: (c) 2013, SoftLayer Technologies, Inc. All rights reserved.
-    :license: BSD, see LICENSE for more details.
+    :license: MIT, see LICENSE for more details.
 """
 
 
@@ -12,7 +12,7 @@ class SoftLayerError(StandardError):
     " The base SoftLayer error. "
 
 
-class Unauthenticated(StandardError):
+class Unauthenticated(SoftLayerError):
     " Unauthenticated "
 
 
