@@ -31,10 +31,10 @@ class HardwareManager(IdentifierMixin, object):
         #: hostname and IP address.
         self.resolvers = [self._get_ids_from_ip, self._get_ids_from_hostname]
 
-    def cancel_hardware(self, id, reason='unneeded', comment=''):
+    def cancel_hardware(self, hardware_id, reason='unneeded', comment=''):
         """ Cancels the specified dedicated server.
 
-        :param int id: The ID of the hardware to be cancelled.
+        :param int hardware_id: The ID of the hardware to be cancelled.
         :param string reason: The reason code for the cancellation. This should
                               come from :func:`get_cancellation_reasons`.
         :param string comment: An optional comment to include with the
@@ -54,11 +54,10 @@ class HardwareManager(IdentifierMixin, object):
         # cancelAssociatedItems
         # attachmentType - Only option is HARDWARE
         ticket_obj = self.client['Ticket']
-        return ticket_obj.createCancelServerTicket(id, cancel_reason,
-                                                   comment, True,
-                                                   'HARDWARE')
+        return ticket_obj.createCancelServerTicket(hardware_id, cancel_reason,
+                                                   comment, True, 'HARDWARE')
 
-    def cancel_metal(self, id, immediate=False):
+    def cancel_metal(self, hardware_id, immediate=False):
         """ Cancels the specified bare metal instance.
 
         :param int id: The ID of the bare metal instance to be cancelled.
@@ -66,7 +65,7 @@ class HardwareManager(IdentifierMixin, object):
                                cancelled immediately. Otherwise, it will be
                                scheduled to cancel on the anniversary date.
         """
-        hw_billing = self.get_hardware(id=id,
+        hw_billing = self.get_hardware(hardware_id,
                                        mask='mask[id, billingItem.id]')
 
         billing_id = hw_billing['billingItem']['id']
@@ -99,7 +98,7 @@ class HardwareManager(IdentifierMixin, object):
 
         """
         if 'mask' not in kwargs:
-            items = set([
+            hw_items = set([
                 'id',
                 'hostname',
                 'domain',
@@ -112,7 +111,14 @@ class HardwareManager(IdentifierMixin, object):
                 'primaryIpAddress',
                 'datacenter',
             ])
-            kwargs['mask'] = "mask[%s]" % ','.join(items)
+            server_items = set([
+                'activeTransaction[id, transactionStatus[friendlyName,name]]',
+            ])
+
+            kwargs['mask'] = '[mask[%s],' \
+                             ' mask(SoftLayer_Hardware_Server)[%s]]' % \
+                             (','.join(hw_items),
+                              ','.join(server_items))
 
         _filter = NestedDict(kwargs.get('filter') or {})
         if tags:
@@ -224,7 +230,7 @@ class HardwareManager(IdentifierMixin, object):
         """
         return self._parse_package_data(package_id)
 
-    def get_hardware(self, id, **kwargs):
+    def get_hardware(self, hardware_id, **kwargs):
         """ Get details about a hardware device
 
         :param integer id: the hardware ID
@@ -248,6 +254,7 @@ class HardwareManager(IdentifierMixin, object):
                 'privateNetworkOnlyFlag',
                 'primaryBackendIpAddress',
                 'primaryIpAddress',
+                'networkManagementIpAddress',
                 'userData',
                 'datacenter',
                 'networkComponents[id, status, speed, maxSpeed, name,'
@@ -256,7 +263,7 @@ class HardwareManager(IdentifierMixin, object):
                 'networkComponents.primarySubnet[id, netmask,'
                 'broadcastAddress, networkIdentifier, gateway]',
                 'hardwareChassis[id,name]',
-                'activeTransaction.id',
+                'activeTransaction[id, transactionStatus[friendlyName,name]]',
                 'operatingSystem.softwareLicense.'
                 'softwareDescription[manufacturer,name,version,referenceCode]',
                 'operatingSystem.passwords[username,password]',
@@ -267,15 +274,15 @@ class HardwareManager(IdentifierMixin, object):
             ])
             kwargs['mask'] = "mask[%s]" % ','.join(items)
 
-        return self.hardware.getObject(id=id, **kwargs)
+        return self.hardware.getObject(id=hardware_id, **kwargs)
 
-    def reload(self, id, post_uri=None):
+    def reload(self, hardware_id, post_uri=None, ssh_keys=None):
         """ Perform an OS reload of a server with its current configuration.
 
-        :param integer id: the instance ID to reload
+        :param integer hardware_id: the instance ID to reload
         :param string post_url: The URI of the post-install script to run
                                 after reload
-
+        :param list ssh_keys: The SSH keys to add to the root user
         """
 
         payload = {
@@ -286,13 +293,16 @@ class HardwareManager(IdentifierMixin, object):
         if post_uri:
             payload['config']['customProvisionScriptUri'] = post_uri
 
-        return self.hardware.reloadOperatingSystem('FORCE', payload['config'],
-                                                   id=id)
+        if ssh_keys:
+            payload['config']['sshKeyIds'] = [key_id for key_id in ssh_keys]
 
-    def change_port_speed(self, id, public, speed):
+        return self.hardware.reloadOperatingSystem('FORCE', payload['config'],
+                                                   id=hardware_id)
+
+    def change_port_speed(self, hardware_id, public, speed):
         """ Allows you to change the port speed of a server's NICs.
 
-        :param int id: The ID of the server
+        :param int hardware_id: The ID of the server
         :param bool public: Flag to indicate which interface to change.
                             True (default) means the public interface.
                             False indicates the private interface.
@@ -303,7 +313,7 @@ class HardwareManager(IdentifierMixin, object):
         else:
             func = self.hardware.setPrivateNetworkInterfaceSpeed
 
-        return func(speed, id=id)
+        return func(speed, id=hardware_id)
 
     def place_order(self, **kwargs):
         """ Places an order for a piece of hardware. See
@@ -459,8 +469,7 @@ class HardwareManager(IdentifierMixin, object):
         order = {
             'hardware': [hardware],
             'location': location,
-            'prices': [
-            ],
+            'prices': [],
         }
 
         if ssh_keys:
@@ -648,13 +657,14 @@ class HardwareManager(IdentifierMixin, object):
 
         return results
 
-    def edit(self, id, userdata=None, hostname=None, domain=None, notes=None):
+    def edit(self, hardware_id, userdata=None, hostname=None, domain=None,
+             notes=None):
         """ Edit hostname, domain name, notes, and/or the user data of the
         hardware
 
         Parameters set to None will be ignored and not attempted to be updated.
 
-        :param integer id: the instance ID to edit
+        :param integer hardware_id: the instance ID to edit
         :param string userdata: user data on the hardware to edit.
                                 If none exist it will be created
         :param string hostname: valid hostname
@@ -665,7 +675,7 @@ class HardwareManager(IdentifierMixin, object):
 
         obj = {}
         if userdata:
-            self.hardware.setUserMetadata([userdata], id=id)
+            self.hardware.setUserMetadata([userdata], id=hardware_id)
 
         if hostname:
             obj['hostname'] = hostname
@@ -679,7 +689,7 @@ class HardwareManager(IdentifierMixin, object):
         if not obj:
             return True
 
-        return self.hardware.editObject(obj, id=id)
+        return self.hardware.editObject(obj, id=hardware_id)
 
 
 def get_default_value(package_options, category):
