@@ -43,7 +43,7 @@ class MetadataManager(object):
 
             >>> import SoftLayer
             >>> client = SoftLayer.Client()
-            >>> from SoftLayer.metadata import MetadataManager
+            >>> from SoftLayer import MetadataManager
             >>> meta = MetadataManager(client)
             >>> meta.get('datacenter')
             'dal05'
@@ -57,6 +57,7 @@ class MetadataManager(object):
     def __init__(self, client=None, timeout=5):
         self.url = API_PRIVATE_ENDPOINT_REST.rstrip('/')
         self.timeout = timeout
+        self.client = client
 
     def make_request(self, path):
         url = '/'.join([self.url, 'SoftLayer_Resource_Metadata', path])
@@ -64,7 +65,7 @@ class MetadataManager(object):
             return make_rest_api_call('GET', url,
                                       http_headers={'User-Agent': USER_AGENT},
                                       timeout=self.timeout)
-        except SoftLayerAPIError, e:
+        except SoftLayerAPIError as e:
             if e.faultCode == 404:
                 return None
             raise e
