@@ -5,8 +5,7 @@
     :copyright: (c) 2013, SoftLayer Technologies, Inc. All rights reserved.
     :license: MIT, see LICENSE for more details.
 """
-from mock import patch, call, Mock, MagicMock
-import datetime
+from mock import patch, call, Mock, MagicMock, ANY
 
 import SoftLayer
 import SoftLayer.API
@@ -84,6 +83,8 @@ class APIClient(unittest.TestCase):
             http_headers={
                 'Content-Type': 'application/xml',
                 'User-Agent': USER_AGENT,
+                'Accept': '*/*',
+                'Accept-Encoding': 'gzip, deflate, compress',
             })
 
     @patch('SoftLayer.API.make_xml_rpc_api_call')
@@ -114,6 +115,8 @@ class APIClient(unittest.TestCase):
                 'RAW': 'HEADER',
                 'Content-Type': 'application/xml',
                 'User-Agent': USER_AGENT,
+                'Accept': '*/*',
+                'Accept-Encoding': 'gzip, deflate, compress',
             })
 
     @patch('SoftLayer.API.make_xml_rpc_api_call')
@@ -130,12 +133,31 @@ class APIClient(unittest.TestCase):
             http_headers={
                 'Content-Type': 'application/xml',
                 'User-Agent': USER_AGENT,
+                'Accept': '*/*',
+                'Accept-Encoding': 'gzip, deflate, compress',
             })
 
     @patch('SoftLayer.API.make_xml_rpc_api_call')
     def test_mask_call_v2_dot(self, make_xml_rpc_api_call):
         self.client['SERVICE'].METHOD(
             mask="mask.something.nested")
+        make_xml_rpc_api_call.assert_called_with(
+            'ENDPOINT/SoftLayer_SERVICE', 'METHOD', (),
+            headers={
+                'authenticate': {
+                    'username': 'doesnotexist', 'apiKey': 'issurelywrong'},
+                'SoftLayer_ObjectMask': {'mask': 'mask.something.nested'}},
+            timeout=None,
+            http_headers={
+                'Content-Type': 'application/xml',
+                'User-Agent': USER_AGENT,
+                'Accept': '*/*',
+                'Accept-Encoding': 'gzip, deflate, compress',
+            })
+
+    @patch('SoftLayer.API.make_xml_rpc_api_call')
+    def test_mask_call_no_mask_prefix(self, make_xml_rpc_api_call):
+        self.client['SERVICE'].METHOD(mask="something.nested")
         make_xml_rpc_api_call.assert_called_with(
             'ENDPOINT/SoftLayer_SERVICE', 'METHOD', (),
             headers={
@@ -146,16 +168,10 @@ class APIClient(unittest.TestCase):
             http_headers={
                 'Content-Type': 'application/xml',
                 'User-Agent': USER_AGENT,
+                'Accept': '*/*',
+                'Accept-Encoding': 'gzip, deflate, compress',
             })
 
-    def test_mask_call_invalid_mask(self):
-        try:
-            self.client['SERVICE'].METHOD(mask="mask[something.nested")
-        except SoftLayer.SoftLayerError, e:
-            self.assertIn('Malformed Mask', str(e))
-        else:
-            self.fail('No exception raised')
-
     @patch('SoftLayer.API.Client.iter_call')
     def test_iterate(self, _iter_call):
         self.client['SERVICE'].METHOD(iter=True)
@@ -231,6 +247,48 @@ class APIClient(unittest.TestCase):
             TypeError,
             self.client.call, 'SERVICE', 'METHOD', invalid_kwarg='invalid')
 
+    @patch('SoftLayer.API.make_xml_rpc_api_call')
+    def test_call_compression_disabled(self, make_xml_rpc_api_call):
+        self.client['SERVICE'].METHOD(compress=False)
+        make_xml_rpc_api_call.assert_called_with(
+            'ENDPOINT/SoftLayer_SERVICE', 'METHOD', (),
+            headers=ANY,
+            timeout=None,
+            http_headers={
+                'Content-Type': 'application/xml',
+                'User-Agent': USER_AGENT,
+            })
+
+    @patch('SoftLayer.API.make_xml_rpc_api_call')
+    def test_call_compression_enabled(self, make_xml_rpc_api_call):
+        self.client['SERVICE'].METHOD(compress=True)
+        make_xml_rpc_api_call.assert_called_with(
+            'ENDPOINT/SoftLayer_SERVICE', 'METHOD', (),
+            headers=ANY,
+            timeout=None,
+            http_headers={
+                'Content-Type': 'application/xml',
+                'User-Agent': USER_AGENT,
+                'Accept': '*/*',
+                'Accept-Encoding': 'gzip, deflate, compress',
+            })
+
+    @patch('SoftLayer.API.make_xml_rpc_api_call')
+    def test_call_compression_override(self, make_xml_rpc_api_call):
+        # raw_headers should override compress=False
+        self.client['SERVICE'].METHOD(
+            compress=False,
+            raw_headers={'Accept-Encoding': 'gzip'})
+        make_xml_rpc_api_call.assert_called_with(
+            'ENDPOINT/SoftLayer_SERVICE', 'METHOD', (),
+            headers=ANY,
+            timeout=None,
+            http_headers={
+                'Content-Type': 'application/xml',
+                'User-Agent': USER_AGENT,
+                'Accept-Encoding': 'gzip',
+            })
+
 
 class APITimedClient(unittest.TestCase):
     def setUp(self):
@@ -238,27 +296,17 @@ class APITimedClient(unittest.TestCase):
             username='doesnotexist', api_key='issurelywrong',
             endpoint_url="ENDPOINT")
 
-    @patch('datetime.datetime')
+    @patch('SoftLayer.API.time.time')
     @patch('SoftLayer.API.Client.call')
-    def test_overriden_call_times_methods(self, _call, datetime_mock):
+    def test_overriden_call_times_methods(self, _call, _time):
         _call.side_effect = [range(10)]
-        total_seconds_mock = Mock()
-        total_seconds_mock.total_seconds = Mock()
-        total_seconds_mock.total_seconds.return_value = 1
-        delta_mock = MagicMock()
-        delta_mock.__sub__ = Mock()
-        delta_mock.__sub__.return_value = total_seconds_mock
-        delta_mock.strftime = Mock()
-        delta_mock.strftime.return_value = 1000
-        now_mock = MagicMock()
-        now_mock.return_value = delta_mock
-        datetime_mock.utcnow = now_mock
+        _time.side_effect = [1121362200, 1121762200]
 
         result = list(self.client.call('SERVICE', 'METHOD'))
 
         self.assertEqual(range(10), result)
 
-        expected_calls = [('SERVICE.METHOD', 1000, 1)]
+        expected_calls = [('SERVICE.METHOD', 1121362200, 400000)]
         self.assertEqual(expected_calls, self.client.get_last_calls())
 
 
