@@ -136,16 +136,17 @@ class CCITests(unittest.TestCase):
         f(expected, results.keys())
 
     def test_cancel_instance(self):
-        self.cci.cancel_instance(id=1)
+        self.cci.cancel_instance(1)
         self.client['Virtual_Guest'].deleteObject.assert_called_once_with(id=1)
 
     def test_reload_instance(self):
         post_uri = 'http://test.sftlyr.ws/test.sh'
-        self.cci.reload_instance(id=1, post_uri=post_uri)
+        self.cci.reload_instance(1, post_uri=post_uri, ssh_keys=[1701])
         service = self.client['Virtual_Guest']
         f = service.reloadOperatingSystem
         f.assert_called_once_with('FORCE',
-                                  {'customProvisionScriptUri': post_uri}, id=1)
+                                  {'customProvisionScriptUri': post_uri,
+                                   'sshKeyIds': [1701]}, id=1)
 
     @patch('SoftLayer.managers.cci.CCIManager._generate_create_dict')
     def test_create_verify(self, create_dict):
@@ -163,23 +164,6 @@ class CCITests(unittest.TestCase):
         self.client['Virtual_Guest'].createObject.assert_called_once_with(
             {'test': 1, 'verify': 1})
 
-    @patch('SoftLayer.managers.cci.CCIManager._generate_create_dict')
-    def test_create_instance_with_ssh_keys(self, create_dict):
-        create_dict.return_value = {'test': 1, 'verify': 1}
-        f = self.client['Virtual_Guest'].generateOrderTemplate
-        f.return_value = {
-            'prices': [100, 200]
-        }
-
-        self.cci.create_instance(test=1, verify=1, ssh_keys=[30, 40])
-
-        create_dict.assert_called_once_with(test=1, verify=1,
-                                            ssh_keys=[30, 40])
-        f.assert_called_once_with({'test': 1, 'verify': 1})
-        self.client['Product_Order'].placeOrder.assert_called_once_with(
-            {'prices': [100, 200], 'sshKeys': [{'sshKeyIds': [30, 40]}]}
-        )
-
     def test_generate_os_and_image(self):
         self.assertRaises(
             ValueError,
@@ -464,7 +448,7 @@ class CCITests(unittest.TestCase):
             'localDiskFlag': True,
             'operatingSystemReferenceCode': "STRING",
             'hourlyBillingFlag': True,
-            'ssh_keys': [543],
+            'sshKeys': [{'id': 543}],
         }
 
         self.assertEqual(data, assert_data)
