@@ -4,12 +4,19 @@
     Utility function/classes
 
     :copyright: (c) 2013, SoftLayer Technologies, Inc. All rights reserved.
-    :license: BSD, see LICENSE for more details.
+    :license: MIT, see LICENSE for more details.
 """
 
 KNOWN_OPERATIONS = ['<=', '>=', '<', '>', '~', '*=', '^=', '$=', '_=', '!~']
 
 
+# Code from http://stackoverflow.com/questions/11700798/python-accessing-values-nested-within-dictionaries  # NOQA
+def lookup(dic, key, *keys):
+    if keys:
+        return lookup(dic.get(key, {}), *keys)
+    return dic.get(key)
+
+
 class NestedDict(dict):
 
     def __getitem__(self, key):
@@ -70,7 +77,7 @@ def query_filter(query):
     return {'operation': query}
 
 
-class IdentifierMixin:
+class IdentifierMixin(object):
     """ This mixin provides an interface to provide multiple methods for
         converting an 'indentifier' to an id """
     resolvers = []
